# Generated by Django 3.2 on 2022-07-28 07:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('private_info', '0002_auto_20220726_1419'),
    ]

    operations = [
        migrations.AddField(
            model_name='userprivatepassword',
            name='encrypt_password',
            field=models.CharField(default='', max_length=512),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='usersimplepassword',
            name='encrypt_password',
            field=models.CharField(default=' ', max_length=512),
            preserve_default=False,
        ),
    ]
